
class Main {
	
	/**
	 * Draws of the lottery
	 */
	static int[][] draws;
	
	/**
	 * Guesses of the players
	 */
	static int[][] guesses;
	
	/**
	 * Random number generator
	 * Do NOT edit the seed values!
	 */
	static final long m = 2147483647;
	static final long b = 12345;
	static final long a = 1103515245;
	static long u = 0;
	
	/**
	 * Constants
	 */
	static final int NUMBER_OF_DRAWS = 5;
	static final int NUMBER_OF_ELEMENT_PER_DRAW = 6;
	static final int MAXIMUM_NUMBER = 49;
	
	/**
	 * Generates a number between 1 and 49
	 */
	static int generateNextRandomNumber() {
		u = (u * a + b) % m;
		double numberBetweenZeroAndOne = (double)u/m;;
		int numberBetweenZeroAndFourtyEight = (int) (MAXIMUM_NUMBER * numberBetweenZeroAndOne);
		return numberBetweenZeroAndFourtyEight + 1;
	}
	
	/**
	 * Generates one draw of 6 numbers between 1 and 49
	 * All numbers are unique
	 */
	static int[] generateOneDraw() {
		int numbers[] = new int[NUMBER_OF_ELEMENT_PER_DRAW];
		for(int i=0; i<numbers.length; ++i) {
			int nextNumber;
			do {
				nextNumber = generateNextRandomNumber();
			} while(numberIsInArray(nextNumber, numbers));
			numbers[i] = nextNumber;
		}
		return numbers;
	}
	
	/**
	 * Returns true if a number is contained in an array
	 */
	static boolean numberIsInArray(int number, int[] array) {
		for(int i=0; i<array.length; ++i) {
			if(array[i] == number) {
				return true;
			}
		}
		return false;
	}
	

	
	/**
	 * TODO Implement a function which generates 5 draws
	 */
	static void generateAllDraws() {
		// Solution: Create the array (otherwise there will be a NULL pointer exception)
		draws = new int[NUMBER_OF_DRAWS][];
		// Solution: Call function generateOneDraw() 5 times
		for(int i=0; i<draws.length; ++i) {
			draws[i] = generateOneDraw();
		}
	}
	
	/**
	 * TODO Implement a function which checks if there is one person with 6 correct numbers
	 * for one of the 5 draws
	 */
	static boolean winnerExists() {
		// Solution: For each draw
		for(int d=0; d<draws.length; ++d) {
			// Solution: For each guess
			for(int p=0; p<guesses.length; ++p) {
				// Solution: Presume the user is a winner
				boolean isWinner = true;
				// Solution: Go through the guesses of the user
				for(int n=0; n<guesses[p].length; ++n) {
					// Solution: If one guess is not among the draws, isWinner will become false
					// Solution: Otherwise isWinner will remain true
					isWinner = isWinner && numberIsInArray(guesses[p][n], draws[d]);
				}
				// Solution: If there is a winner, return true
				if(isWinner) {
					return true;
				}
			}
		}
		// Solution: If we reach this part of the code, then there is no winner
		return false;
	}

		
	/**
	 * This is the main function. It reads a number from the input to determine the test case.
	 */
	public static void main(String[] args) {
		
		java.util.Scanner scanner = new java.util.Scanner(System.in);
		int testCase = scanner.nextInt();
		
		if(testCase == 1) {
			// Task 1 - Generate the draws
			generateAllDraws();
			printDraws();
		} else if(testCase == 2) {
			// Task 2 - Check if there is a winner
			while (scanner.hasNextInt()){
				readGuesses(scanner);
				generateAllDraws();
				if(winnerExists()) {
					System.out.println("There is at least one winner!");
				} else {
					System.out.println("There is no winner.");
				}
			}			
		}
		scanner.close();
		
	}
	
	/**
	 * Outputs the draws of the lottery
	 */
	static void printDraws() {
		for(int i=0; i<draws.length; ++i) {
			for(int j=0; j<draws[i].length; ++j) {
				System.out.print(draws[i][j] + " ");
			}
			System.out.println();
		}
	}
	
	/**
	 * Reads the guesses from the command line
	 */
	static void readGuesses(java.util.Scanner input) {
		
		int numberOfPlayers = input.nextInt();
		guesses = new int[numberOfPlayers][];		
		for(int i=0; i<numberOfPlayers; ++i) {
			guesses[i] = new int[NUMBER_OF_ELEMENT_PER_DRAW];
			for(int j=0; j<guesses[i].length; ++j) {
				guesses[i][j] = input.nextInt();
			}
		}
		
	}

}
